@@ -23,13 +23,16 @@ import yaml
 from lxml import etree
 from PIL import Image, ImageColor, ImageDraw, ImageFont, ImageOps
 from pydantic import BaseModel, Field, PrivateAttr, validator
+from pydantic.fields import Undefined
 from rich.console import Console
+from rich.table import Table
 from StreamDeck.DeviceManager import DeviceManager
 from StreamDeck.ImageHelpers import PILHelper
 
 if TYPE_CHECKING:
     from collections.abc import Coroutine
 
+    import pandas as pd
     from StreamDeck.Devices import StreamDeck
 
 __version__ = pkg_resources.get_distribution("home_assistant_streamdeck_yaml").version
@@ -179,8 +182,8 @@ class Button(BaseModel, extra="forbid"):  # type: ignore[call-arg]
         return cls(**data[0])
 
     @classmethod
-    def to_markdown_table(cls: type[Button]) -> str:
-        """Return a markdown table with the schema."""
+    def to_pandas_table(cls: type[Button]) -> pd.DataFrame:
+        """Return a pandas table with the schema."""
         import pandas as pd
 
         rows = []
@@ -197,10 +200,15 @@ class Button(BaseModel, extra="forbid"):  # type: ignore[call-arg]
                 "Allow template": "✅" if info.extra["allow_template"] else "❌",
                 "Description": info.description,
                 "Default": code(info.default) if info.default else "",
-                "Type": code(field._type_display()),  # noqa: SLF001
+                "Type": code(field._type_display()),
             }
             rows.append(row)
-        return pd.DataFrame(rows).to_markdown(index=False)
+        return pd.DataFrame(rows)
+
+    @classmethod
+    def to_markdown_table(cls: type[Button]) -> str:
+        """Return a markdown table with the schema."""
+        return cls.to_pandas_table().to_markdown(index=False)
 
     @property
     def domain(self) -> str | None:
@@ -436,24 +444,102 @@ def _to_filename(id_: str, suffix: str = "") -> Path:
     return filename.with_suffix(suffix)
 
 
+def to_pandas_table(cls: type[BaseModel]) -> pd.DataFrame:
+    """Return a markdown table with the schema."""
+    import pandas as pd
+
+    rows = []
+    for k, field in cls.__fields__.items():
+        info = field.field_info
+        if info.description is None:
+            continue
+
+        def code(text: str) -> str:
+            return f"`{text}`"
+
+        row = {
+            "Variable name": code(k),
+            "Description": info.description,
+            "Default": code(info.default) if info.default is not Undefined else "",
+            "Type": code(field._type_display()),
+        }
+        rows.append(row)
+    return pd.DataFrame(rows)
+
+
+def _pandas_to_rich_table(df: pd.DataFrame) -> Table:
+    """Return a rich table from a pandas DataFrame."""
+    table = Table()
+
+    # Add the columns
+    for column in df.columns:
+        table.add_column(column)
+
+    # Add the rows
+    for _, row in df.iterrows():
+        table.add_row(*row.astype(str).tolist())
+
+    return table
+
+
 class Page(BaseModel):
     """A page of buttons."""
 
-    name: str
-    buttons: list[Button] = Field(default_factory=list)
+    name: str = Field(description="The name of the page.")
+    buttons: list[Button] = Field(
+        default_factory=list,
+        description="A list of buttons on the page.",
+    )
+
+    @classmethod
+    def to_pandas_table(cls: type[Page]) -> pd.DataFrame:
+        """Return a pandas DataFrame with the schema."""
+        return to_pandas_table(cls)
+
+    @classmethod
+    def to_markdown_table(cls: type[Page]) -> str:
+        """Return a markdown table with the schema."""
+        return cls.to_pandas_table().to_markdown(index=False)
 
 
 class Config(BaseModel):
     """Configuration file."""
 
-    pages: list[Page] = Field(default_factory=list)
-    anonymous_pages: list[Page] = Field(default_factory=list)
-    current_page_index: int = 0
-    state_entity_id: str | None = None
-    is_on: bool = True
-    brightness: int = 100
+    pages: list[Page] = Field(
+        default_factory=list,
+        description="A list of `Page`s in the configuration.",
+    )
+    anonymous_pages: list[Page] = Field(
+        default_factory=list,
+        description="A list of anonymous Pages in the configuration."
+        " These pages are hidden and not displayed when cycling through the pages."
+        " They can only be reached using the `special_type: 'go-to-page'` button."
+        " Designed for single use, these pages return to the previous page"
+        " upon clicking a button.",
+    )
+    state_entity_id: str | None = Field(
+        default=None,
+        description="The entity ID to sync display state with. For"
+        " example `input_boolean.streamdeck` or `binary_sensor.anyone_home`.",
+    )
+    brightness: int = Field(
+        default=100,
+        description="The default brightness of the Stream Deck (0-100).",
+    )
+    _current_page_index: int = PrivateAttr(default=0)
+    _is_on: bool = PrivateAttr(default=True)
     _detached_page: Page | None = PrivateAttr(default=None)
 
+    @classmethod
+    def to_pandas_table(cls: type[Config]) -> pd.DataFrame:
+        """Return a pandas DataFrame with the schema."""
+        return to_pandas_table(cls)
+
+    @classmethod
+    def to_markdown_table(cls: type[Config]) -> str:
+        """Return a markdown table with the schema."""
+        return cls.to_pandas_table().to_markdown(index=False)
+
     def update_timers(
         self,
         deck: StreamDeck,
@@ -474,29 +560,29 @@ class Config(BaseModel):
 
     def next_page(self) -> Page:
         """Go to the next page."""
-        self.current_page_index = self.next_page_index
-        return self.pages[self.current_page_index]
+        self._current_page_index = self.next_page_index
+        return self.pages[self._current_page_index]
 
     @property
     def next_page_index(self) -> int:
         """Return the next page index."""
-        return (self.current_page_index + 1) % len(self.pages)
+        return (self._current_page_index + 1) % len(self.pages)
 
     @property
     def previous_page_index(self) -> int:
         """Return the previous page index."""
-        return (self.current_page_index - 1) % len(self.pages)
+        return (self._current_page_index - 1) % len(self.pages)
 
     def previous_page(self) -> Page:
         """Go to the previous page."""
-        self.current_page_index = self.previous_page_index
-        return self.pages[self.current_page_index]
+        self._current_page_index = self.previous_page_index
+        return self.pages[self._current_page_index]
 
     def current_page(self) -> Page:
         """Return the current page."""
         if self._detached_page is not None:
             return self._detached_page
-        return self.pages[self.current_page_index]
+        return self.pages[self._current_page_index]
 
     def button(self, key: int) -> Button | None:
         """Return the button for a key."""
@@ -508,12 +594,12 @@ class Config(BaseModel):
     def to_page(self, page: int | str) -> Page:
         """Go to a page based on the page name or index."""
         if isinstance(page, int):
-            self.current_page_index = page
+            self._current_page_index = page
             return self.current_page()
 
         for i, p in enumerate(self.pages):
             if p.name == page:
-                self.current_page_index = i
+                self._current_page_index = i
                 return self.current_page()
 
         for p in self.anonymous_pages:
@@ -1183,20 +1269,20 @@ def read_config(fname: Path) -> Config:
 
 def turn_on(config: Config, deck: StreamDeck, complete_state: StateDict) -> None:
     """Turn on the Stream Deck and update all key images."""
-    console.log(f"Calling turn_on, with {config.is_on=}")
-    if config.is_on:
+    console.log(f"Calling turn_on, with {config._is_on=}")
+    if config._is_on:
         return
-    config.is_on = True
+    config._is_on = True
     update_all_key_images(deck, config, complete_state)
     deck.set_brightness(config.brightness)
 
 
 def turn_off(config: Config, deck: StreamDeck) -> None:
     """Turn off the Stream Deck."""
-    console.log(f"Calling turn_off, with {config.is_on=}")
-    if not config.is_on:
+    console.log(f"Calling turn_off, with {config._is_on=}")
+    if not config._is_on:
         return
-    config.is_on = False
+    config._is_on = False
     # This resets all buttons except the turn-off button that
     # was just pressed, however, this doesn't matter with the
     # 0 brightness. Unless no button was pressed.
@@ -1211,7 +1297,7 @@ async def _handle_key_press(
     button: Button,
     deck: StreamDeck,
 ) -> None:
-    if not config.is_on:
+    if not config._is_on:
         turn_on(config, deck, complete_state)
         return
 
@@ -1240,7 +1326,7 @@ async def _handle_key_press(
             colormap=button.special_type_data.get("colormap", None),
             colors=button.special_type_data.get("colors", None),
         )
-        config._detached_page = page  # noqa: SLF001
+        config._detached_page = page
         update_all()
         return  # to skip the _detached_page reset below
     elif button.service is not None:
@@ -1255,8 +1341,8 @@ async def _handle_key_press(
         assert button.service is not None  # for mypy
         await call_service(websocket, button.service, service_data, button.target)
 
-    if config._detached_page:  # noqa: SLF001
-        config._detached_page = None  # noqa: SLF001
+    if config._detached_page:
+        config._detached_page = None
         update_all()
 
 
@@ -1531,6 +1617,25 @@ async def run(
         await handle_changes(websocket, complete_state, deck, config)
 
 
+def _rich_table_str(df: pd.DataFrame) -> str:
+    table = _pandas_to_rich_table(df)
+    console = Console(file=io.StringIO(), width=120)
+    console.print(table)
+    return console.file.getvalue()
+
+
+def _help() -> str:
+    try:
+        return (
+            f"See the configuration options below:\n\n"
+            f"Config YAML options:\n{_rich_table_str(Config.to_pandas_table())}\n\n"
+            f"Page YAML options:\n{_rich_table_str(Page.to_pandas_table())}\n\n"
+            f"Button YAML options:\n{_rich_table_str(Button.to_pandas_table())}\n\n"
+        )
+    except ModuleNotFoundError:
+        return ""
+
+
 def main() -> None:
     """Start the Stream Deck integration."""
     import argparse
@@ -1540,7 +1645,10 @@ def main() -> None:
 
     load_dotenv()
 
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(
+        epilog=_help(),
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+    )
     parser.add_argument("--host", default=os.environ.get("HASS_HOST", "localhost"))
     parser.add_argument("--token", default=os.environ.get("HASS_TOKEN"))
     parser.add_argument(
